# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/beforerr_dev',
                'doc_host': 'https://Beforerr.github.io',
                'git_url': 'https://github.com/Beforerr/beforerr_dev',
                'lib_path': 'beforerr'},
  'syms': { 'beforerr.basics': {'beforerr.basics.pmap': ('basics.html#pmap', 'beforerr/basics.py')},
            'beforerr.core': {'beforerr.core.ifnone': ('core.html#ifnone', 'beforerr/core.py')},
            'beforerr.io.json': {},
            'beforerr.io.pickle': {},
            'beforerr.matplotlib': { 'beforerr.matplotlib.unify_axes_fontsize': ( 'matplotlib.html#unify_axes_fontsize',
                                                                                  'beforerr/matplotlib.py'),
                                     'beforerr.matplotlib.unify_axis_fontsize': ( 'matplotlib.html#unify_axis_fontsize',
                                                                                  'beforerr/matplotlib.py')},
            'beforerr.polars': { 'beforerr.polars._expand_selectors': ('polars.html#_expand_selectors', 'beforerr/polars.py'),
                                 'beforerr.polars.convert_to_pd_dataframe': ('polars.html#convert_to_pd_dataframe', 'beforerr/polars.py'),
                                 'beforerr.polars.decompose_vector': ('polars.html#decompose_vector', 'beforerr/polars.py'),
                                 'beforerr.polars.filter_df_by_ranges': ('polars.html#filter_df_by_ranges', 'beforerr/polars.py'),
                                 'beforerr.polars.filter_series_by_ranges_i': ( 'polars.html#filter_series_by_ranges_i',
                                                                                'beforerr/polars.py'),
                                 'beforerr.polars.pl_norm': ('polars.html#pl_norm', 'beforerr/polars.py'),
                                 'beforerr.polars.sort': ('polars.html#sort', 'beforerr/polars.py')},
            'beforerr.project': { 'beforerr.project.append_prefix_suffix': ('projects.html#append_prefix_suffix', 'beforerr/project.py'),
                                  'beforerr.project.datadir': ('projects.html#datadir', 'beforerr/project.py'),
                                  'beforerr.project.increment_backup_num': ('projects.html#increment_backup_num', 'beforerr/project.py'),
                                  'beforerr.project.produce_or_load': ('projects.html#produce_or_load', 'beforerr/project.py'),
                                  'beforerr.project.produce_or_load_file': ('projects.html#produce_or_load_file', 'beforerr/project.py'),
                                  'beforerr.project.projectdir': ('projects.html#projectdir', 'beforerr/project.py'),
                                  'beforerr.project.safesave': ('projects.html#safesave', 'beforerr/project.py'),
                                  'beforerr.project.savename': ('projects.html#savename', 'beforerr/project.py'),
                                  'beforerr.project.setup_run_dir': ('projects.html#setup_run_dir', 'beforerr/project.py'),
                                  'beforerr.project.valtostring': ('projects.html#valtostring', 'beforerr/project.py')},
            'beforerr.r': {'beforerr.r.py2rpy_polars': ('r.html#py2rpy_polars', 'beforerr/r.py')}}}
